@@ -36,10 +36,12 @@
 ;;; Code:
 
 (require 'seq)
+(require 'color)
 (eval-when-compile (require 'subr-x))
 
 (defconst doric-themes-light-themes
-  '(doric-cherry
+  '(doric-beach
+    doric-cherry
     doric-earth
     doric-light
     doric-marble
@@ -53,6 +55,7 @@
     doric-obsidian
     doric-pine
     doric-plum
+    doric-valley
     doric-water)
   "Dark themes.")
 
@@ -344,10 +347,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     substitute-match))
 
 (defconst doric-themes-intense-shadow-foreground-only-faces
-  '(all-the-icons-completion-dir-face
-    all-the-icons-dired-dir-face
-    all-the-icons-ibuffer-dir-face
-    calendar-month-header
+  '(calendar-weekday-header
     change-log-date
     denote-faces-date
     denote-faces-day
@@ -370,9 +370,8 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     magit-log-author
     magit-log-date
     marginalia-date
-    nerd-icons-completion-dir-face
-    nerd-icons-dired-dir-face
-    nerd-icons-ibuffer-dir-face
+    message-header-cc
+    message-header-other
     notmuch-search-date
     org-agenda-calendar-daterange
     org-agenda-column-dateline
@@ -389,6 +388,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     company-tooltip-scrollbar-track
     consult-preview-line
     corfu-popupinfo
+    diary
     ediff-even-diff-A
     ediff-even-diff-Ancestor
     ediff-even-diff-B
@@ -414,6 +414,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     notmuch-crypto-signature-good-key
     notmuch-crypto-signature-unknown
     org-agenda-clocking
+    org-agenda-diary
     org-agenda-restriction-lock
     org-clock-overlay
     secondary-selection
@@ -434,11 +435,13 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
 (defconst doric-themes-subtle-shadow-foreground-only-faces
   '(all-the-icons-blue
     all-the-icons-blue-alt
+    all-the-icons-completion-dir-face
     all-the-icons-cyan
     all-the-icons-cyan-alt
     all-the-icons-dblue
     all-the-icons-dcyan
     all-the-icons-dgreen
+    all-the-icons-dired-dir-face
     all-the-icons-dmaroon
     all-the-icons-dorange
     all-the-icons-dpink
@@ -447,6 +450,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     all-the-icons-dsilver
     all-the-icons-dyellow
     all-the-icons-green
+    all-the-icons-ibuffer-dir-face
     all-the-icons-ibuffer-file-face
     all-the-icons-ibuffer-mode-face
     all-the-icons-ibuffer-size-face
@@ -545,19 +549,18 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     marginalia-type
     marginalia-value
     marginalia-version
-    markdown-metadata-key-face
-    message-header-mml
-    message-header-name
     message-header-newsgroups
     message-header-xheader
     mu4e-header-face
     nerd-icons-blue
     nerd-icons-blue-alt
+    nerd-icons-completion-dir-face
     nerd-icons-cyan
     nerd-icons-cyan-alt
     nerd-icons-dblue
     nerd-icons-dcyan
     nerd-icons-dgreen
+    nerd-icons-dired-dir-face
     nerd-icons-dmaroon
     nerd-icons-dorange
     nerd-icons-dpink
@@ -566,6 +569,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     nerd-icons-dsilver
     nerd-icons-dyellow
     nerd-icons-green
+    nerd-icons-ibuffer-dir-face
     nerd-icons-ibuffer-file-face
     nerd-icons-ibuffer-mode-face
     nerd-icons-ibuffer-size-face
@@ -597,18 +601,14 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     notmuch-tree-no-match-face
     org-agenda-dimmed-todo-face
     org-agenda-done
-    org-agenda-structure-secondary
     org-column
     org-done
     org-headline-done
-    org-scheduled
-    org-scheduled-today
     org-special-keyword
     org-tag
     org-time-grid
     org-upcoming-deadline
     org-upcoming-distant-deadline
-    package-help-section-name
     package-status-available
     package-status-built-in
     package-status-dependency
@@ -625,8 +625,8 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     transient-inactive-value
     transient-unreachable
     transient-unreachable-key
-    vertico-multiline
     vc-ignored-state
+    vertico-multiline
     window-divider
     window-divider-first-pixel
     window-divider-last-pixel
@@ -658,6 +658,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     notmuch-tree-match-author-face
     notmuch-search-flagged-face
     org-headline-todo
+    org-scheduled-previously
     org-table-row
     org-todo
     org-warning
@@ -688,7 +689,6 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     consult-file
     denote-faces-prompt-current-name
     denote-faces-title
-    diary
     dictionary-word-definition-face
     dired-mark
     dired-perm-write
@@ -721,7 +721,6 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     icomplete-vertical-selected-prefix-indicator-face
     ido-only-match
     icon
-    log-edit-header
     kmacro-menu-flagged
     kmacro-menu-mark
     kmacro-menu-marked
@@ -762,20 +761,18 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     notmuch-tag-unread
     notmuch-tag-flagged
     org-agenda-current-time
-    org-agenda-date
-    org-agenda-date-weekend
-    org-agenda-diary
     org-agenda-filter-category
     org-agenda-filter-effort
     org-agenda-filter-regexp
     org-agenda-filter-tags
-    org-agenda-structure-filter
     org-archived
     org-default
     org-document-info
     org-inline-src-block
     org-latex-and-related
     org-mode-line-clock
+    org-scheduled
+    org-scheduled-today
     proced-cpu
     proced-mark
     proced-memory-low-usage
@@ -809,7 +806,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     breadcrumb-imenu-leaf-face
     breadcrumb-project-leaf-face
     buffer-menu-buffer
-    calendar-weekday-header
+    calendar-month-header
     change-log-name
     change-log-file
     circe-prompt-face
@@ -839,15 +836,12 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     denote-faces-subdirectory
     dictionary-button-face
     diff-nonexistent
-    dired-header
-    diredfl-dir-heading
     ediff-fine-diff-Ancestor
     edmacro-label
     elfeed-log-debug-level-face
     elfeed-log-error-level-face
     elfeed-log-info-level-face
     elfeed-log-warn-level-face
-    elfeed-search-unread-title-face
     erc-prompt-face
     eshell-ls-archive
     eshell-ls-backup
@@ -869,9 +863,6 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     font-lock-regexp-grouping-backslash
     font-lock-regexp-grouping-construct
     geiser-font-lock-repl-prompt
-    git-commit-comment-action
-    git-commit-comment-branch-local
-    git-commit-comment-heading
     git-commit-summary
     gnus-emphasis-bold
     gnus-header-content
@@ -922,16 +913,12 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     markdown-header-face-4
     markdown-header-face-5
     markdown-header-face-6
-    message-header-cc
-    message-header-other
     message-header-subject
     message-header-to
     minibuffer-prompt
     mode-line-buffer-id
     mode-line-emphasis
-    org-agenda-date-today
-    org-agenda-date-weekend-today
-    org-agenda-structure
+    org-agenda-date
     org-checkbox-statistics-done
     org-checkbox-statistics-todo
     org-document-title
@@ -994,6 +981,19 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     ztreep-diff-header-face
     ztreep-header-face))
 
+(defconst doric-themes-bold-intense-faces
+  '(dired-header
+    diredfl-dir-heading
+    elfeed-search-unread-title-face
+    git-commit-comment-heading
+    git-commit-summary
+    log-edit-header
+    magit-section-heading
+    markdown-metadata-key-face
+    message-header-name
+    org-agenda-structure
+    package-help-section-name))
+
 (defconst doric-themes-bold-italic-faces
   '(appt-notification
     aw-key-face
@@ -1018,6 +1018,9 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     font-lock-builtin-face
     font-lock-preprocessor-face
     font-lock-type-face
+    git-commit-comment-action
+    git-commit-comment-branch-remote
+    git-commit-comment-branch-local
     gnus-emphasis-bold-italic
     gnus-server-denied
     ibuffer-locked-buffer
@@ -1067,6 +1070,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     custom-state
     custom-themed
     diary-anniversary
+    diary-time
     diff-function
     diff-index
     elfeed-search-tag-face
@@ -1095,7 +1099,6 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     gnus-group-news-low-empty
     gnus-server-offline
     help-argument-name
-    holiday
     line-number-minor-tick
     magit-branch-current
     magit-cherry-unmatched
@@ -1110,6 +1113,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     notmuch-wash-cited-text
     org-agenda-calendar-event
     org-agenda-calendar-sexp
+    org-agenda-structure-secondary
     org-inline-src-block
     org-latex-and-related
     org-macro
@@ -1188,14 +1192,22 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
   '(denote-faces-prompt-new-name
     diff-added
     diff-indicator-added
-    ediff-current-diff-B
-    magit-diff-added-highlight
+    magit-diff-added
     magit-diffstat-added
     smerge-lower
     ztreep-diff-model-add-face))
 
-(defconst doric-themes-diff-added-faces-foreground-only
-  '(magit-diff-added))
+(defconst doric-themes-diff-added-highlight-faces
+  '(ediff-current-diff-B
+    magit-diff-added-highlight))
+
+(defconst doric-themes-diff-changed-highlight-faces
+  '(ediff-current-diff-C
+    magit-diff-base-highlight))
+
+(defconst doric-themes-diff-removed-highlight-faces
+  '(ediff-current-diff-A
+    magit-diff-removed-highlight))
 
 (defconst doric-themes-diff-added-refine-faces
   '(diff-refine-added
@@ -1206,13 +1218,9 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
   '(diff-changed
     diff-changed-unspecified
     diff-indicator-changed
-    ediff-current-diff-C
-    magit-diff-base-highlight
+    magit-diff-base
     smerge-base))
 
-(defconst doric-themes-diff-changed-faces-foreground-only
-  '(magit-diff-base))
-
 (defconst doric-themes-diff-changed-refine-faces
   '(diff-refine-changed
     ediff-fine-diff-C
@@ -1222,15 +1230,11 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
   '(denote-faces-prompt-old-name
     diff-removed
     diff-indicator-removed
-    ediff-current-diff-A
-    magit-diff-removed-highlight
+    magit-diff-removed
     magit-diffstat-removed
     smerge-upper
     ztreep-diff-model-diff-face))
 
-(defconst doric-themes-diff-removed-faces-foreground-only
-  '(magit-diff-removed))
-
 (defconst doric-themes-diff-removed-refine-faces
   '(diff-refine-removed
     ediff-fine-diff-A
@@ -1297,6 +1301,21 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     mu4e-cited-4-face
     mu4e-cited-6-face))
 
+(defgroup doric-themes-faces ()
+  "Faces defined by the Doric themes."
+  :group 'doric-themes
+  :link '(url-link :tag "Sample pictures" "https://protesilaos.com/emacs/doric-themes-pictures")
+  :prefix "doric-themes-"
+  :tag "Doric themes Faces")
+
+(dolist (scope '(note warning error))
+  (custom-declare-face
+   (intern (format "doric-themes-prominent-%s" scope))
+   nil (format "Prominent notification of type %s." scope)
+   :package-version '(doric-themes . "0.4.0")
+   :version "30.1"
+   :group 'doric-themes-faces))
+
 (defun doric-themes-prepare-faces (&rest faces-and-attributes)
   "Set faces to their respective attributes in FACES-AND-ATTRIBUTES."
   (pcase-let ((`(,faces . ,attributes) faces-and-attributes))
@@ -1305,9 +1324,19 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
        (backquote (list ',face (list (list t ,@attributes)))))
      faces)))
 
+(defun doric-themes-adjust-value (hex-rgb percentage)
+  "Adjust value of HEX-RGB colour by PERCENTAGE."
+  (pcase-let* ((`(,r ,g ,b) (color-name-to-rgb hex-rgb))
+               (fn (if (color-dark-p (list r g b))
+                       #'color-lighten-name
+                     #'color-darken-name)))
+    (funcall fn hex-rgb percentage)))
+
 ;;;###autoload
-(defmacro doric-themes-define-theme (name background-mode)
-  "Define theme with NAME and `light' or `dark' BACKGROUND-MODE."
+(defmacro doric-themes-define-theme (name background-mode &optional description)
+  "Define theme with NAME and `light' or `dark' BACKGROUND-MODE.
+With optional DESCRIPTION use it to describe the theme, otherwise
+default a generic text that mentions the BACKGROUND-MODE."
   (declare (indent 0))
   (unless (memq background-mode '(light dark))
     (error "The BACKGROUND-MODE must be either `light' or `dark'"))
@@ -1315,7 +1344,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
       `(progn
          (custom-declare-theme
           ',name 'doric-themes
-          ,(format "Minimalist %s theme." background-mode)
+          ,(or description (format "Minimalist %s theme." background-mode))
           (list :kind 'color-scheme :background-mode ',background-mode :family 'doric))
          (let ,palette
            (custom-theme-set-faces
@@ -1396,6 +1425,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
             ,@(doric-themes-prepare-faces doric-themes-success-underline-faces :underline '(list :style 'wave :color fg-cyan))
 
             ,@(doric-themes-prepare-faces doric-themes-bold-faces :inherit ''bold :foreground 'fg-shadow-intense)
+            ,@(doric-themes-prepare-faces doric-themes-bold-intense-faces :inherit ''bold :foreground 'fg-main)
             ,@(doric-themes-prepare-faces doric-themes-bold-italic-faces :inherit ''bold-italic :foreground 'fg-shadow-subtle)
             ,@(doric-themes-prepare-faces doric-themes-italic-faces :inherit ''italic :foreground 'fg-shadow-subtle)
             ,@(doric-themes-prepare-faces doric-themes-underline-link-faces :inherit ''underline :foreground 'fg-accent)
@@ -1403,19 +1433,23 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
 
             ,@(doric-themes-prepare-faces doric-themes-selection-faces :background 'bg-accent)
 
-            ,@(doric-themes-prepare-faces doric-themes-diff-added-faces :background 'bg-green :foreground 'fg-green)
-            ,@(doric-themes-prepare-faces doric-themes-diff-added-faces-foreground-only :foreground 'fg-green)
-            ,@(doric-themes-prepare-faces doric-themes-diff-added-refine-faces :inherit ''bold)
-            ,@(doric-themes-prepare-faces doric-themes-diff-changed-faces :background 'bg-yellow :foreground 'fg-yellow)
-            ,@(doric-themes-prepare-faces doric-themes-diff-changed-faces-foreground-only :foreground 'fg-yellow)
-            ,@(doric-themes-prepare-faces doric-themes-diff-changed-refine-faces :inherit ''bold)
-            ,@(doric-themes-prepare-faces doric-themes-diff-removed-faces :background 'bg-red :foreground 'fg-red)
-            ,@(doric-themes-prepare-faces doric-themes-diff-removed-faces-foreground-only :foreground 'fg-red)
-            ,@(doric-themes-prepare-faces doric-themes-diff-removed-refine-faces :inherit ''bold)
+            ,@(doric-themes-prepare-faces doric-themes-diff-added-faces :background '(doric-themes-adjust-value bg-green -10) :foreground 'fg-neutral)
+            ,@(doric-themes-prepare-faces doric-themes-diff-added-highlight-faces :background 'bg-green :foreground 'fg-green)
+            ,@(doric-themes-prepare-faces doric-themes-diff-added-refine-faces :inherit ''bold :background '(doric-themes-adjust-value bg-green 10))
+            ,@(doric-themes-prepare-faces doric-themes-diff-changed-faces :background '(doric-themes-adjust-value bg-yellow -10) :foreground 'fg-neutral)
+            ,@(doric-themes-prepare-faces doric-themes-diff-changed-highlight-faces :background 'bg-yellow :foreground 'fg-yellow)
+            ,@(doric-themes-prepare-faces doric-themes-diff-changed-refine-faces :inherit ''bold :background '(doric-themes-adjust-value bg-yellow 10))
+            ,@(doric-themes-prepare-faces doric-themes-diff-removed-faces :background '(doric-themes-adjust-value bg-red -10) :foreground 'fg-neutral)
+            ,@(doric-themes-prepare-faces doric-themes-diff-removed-highlight-faces :background 'bg-red :foreground 'fg-red)
+            ,@(doric-themes-prepare-faces doric-themes-diff-removed-refine-faces :inherit ''bold :background '(doric-themes-adjust-value bg-red 10))
 
             ,@(doric-themes-prepare-faces doric-themes-cite-odd :inherit ''italic :foreground 'fg-accent)
             ,@(doric-themes-prepare-faces doric-themes-cite-even :inherit ''italic :foreground 'fg-shadow-subtle)
 
+            `(doric-themes-prominent-error ((t :background ,bg-red :foreground ,fg-red)))
+            `(doric-themes-prominent-warning ((t :background ,bg-yellow :foreground ,fg-yellow)))
+            `(doric-themes-prominent-note ((t :background ,bg-cyan :foreground ,fg-cyan)))
+
             '(embark-keybinding ((t :inherit (fixed-pitch bold-italic))))
 
             `(font-lock-comment-delimiter-face ((t :inherit italic :foreground ,fg-accent)))
@@ -1472,6 +1506,8 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
                (((class color) (min-colors 88) (background dark))
                 :background "#000000" :foreground "#cab000")))
 
+            `(holiday ((t :inherit bold :background ,bg-shadow-subtle :foreground ,fg-main)))
+
             `(isearch ((t :background ,bg-shadow-intense :foreground ,fg-main)))
             `(isearch-fail ((t :inherit (underline bold))))
             `(isearch-group-1 ((t :background ,bg-accent :foreground ,fg-accent)))
@@ -1480,10 +1516,23 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
 
             '(help-key-binding ((t :inherit (fixed-pitch bold-italic))))
 
-            '(line-number-current-line ((t :inherit (highlight bold))))
-
             `(keycast-key ((t :inherit bold-italic :background ,fg-shadow-intense :foreground ,bg-main)))
 
+            `(lin-blue ((t :background ,bg-blue)))
+            `(lin-cyan ((t :background ,bg-cyan)))
+            `(lin-green ((t :background ,bg-green)))
+            `(lin-magenta ((t :background ,bg-magenta)))
+            `(lin-red ((t :background ,bg-red)))
+            `(lin-yellow ((t :background ,bg-yellow)))
+            `(lin-blue-override-fg ((t :background ,bg-blue :foreground ,fg-main)))
+            `(lin-cyan-override-fg ((t :background ,bg-cyan :foreground ,fg-main)))
+            `(lin-green-override-fg ((t :background ,bg-green :foreground ,fg-main)))
+            `(lin-magenta-override-fg ((t :background ,bg-magenta :foreground ,fg-main)))
+            `(lin-red-override-fg ((t :background ,bg-red :foreground ,fg-main)))
+            `(lin-yellow-override-fg ((t :background ,bg-yellow :foreground ,fg-main)))
+
+            `(line-number-current-line ((t :inherit bold :background ,bg-accent :foreground ,fg-accent)))
+
             `(magit-diff-context-highlight ((t :background ,bg-shadow-subtle :foreground ,fg-shadow-subtle)))
             `(magit-diff-file-heading ((t :inherit bold :foreground ,fg-accent)))
             `(magit-diff-file-heading-highlight ((t :inherit magit-diff-file-heading :background ,bg-shadow-subtle)))
@@ -1492,7 +1541,6 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
             `(magit-diff-hunk-heading-highlight ((t :inherit bold :background ,bg-neutral)))
             `(magit-diff-hunk-heading-selection ((t :inherit bold :background ,bg-accent)))
             `(magit-diff-lines-heading ((t :background ,fg-shadow-subtle :foreground ,bg-main)))
-            `(magit-section-heading ((t :inherit bold)))
             `(magit-section-heading-selection ((t :inherit bold :background ,bg-accent)))
             `(magit-section-highlight ((t :background ,bg-shadow-subtle)))
 
@@ -1519,7 +1567,11 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
             `(notmuch-message-summary-face
               ((default :background ,bg-shadow-subtle)
                (((supports :overline t))
-                 :overline ,fg-shadow-subtle)))
+                :overline ,fg-shadow-subtle)))
+
+            `(org-agenda-date-weekend ((t :inherit (bold shadow))))
+            `(org-agenda-date-today ((t :inherit (underline org-agenda-date))))
+            `(org-agenda-date-weekend-today ((t :inherit (underline org-agenda-date-weekend))))
 
             `(org-block ((t :inherit fixed-pitch :background ,bg-shadow-subtle :extend t)))
             `(org-block-begin-line ((t :inherit fixed-pitch :background ,bg-neutral :foreground ,fg-neutral :extend t)))
@@ -1541,7 +1593,6 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
             `(org-meta-line ((t :inherit fixed-pitch :foreground ,fg-shadow-subtle)))
             '(org-property-value ((t :inherit fixed-pitch)))
             '(org-quote ((t :inherit org-block)))
-            `(org-scheduled-previously ((t :inherit bold :foreground ,fg-shadow-subtle)))
             `(org-verbatim ((t :inherit (fixed-pitch italic) :foreground ,fg-shadow-subtle)))
             '(org-verse ((t :inherit org-block)))
             `(org-table ((t :inherit fixed-pitch :foreground ,fg-accent)))
@@ -1549,6 +1600,13 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
             `(package-mark-delete-line ((t :inherit bold-italic :background ,bg-shadow-intense :foreground ,fg-main)))
             `(package-mark-install-line ((t :inherit bold-italic :background ,bg-accent :foreground ,fg-main)))
 
+            `(pulsar-blue ((t :background ,bg-blue)))
+            `(pulsar-cyan ((t :background ,bg-cyan)))
+            `(pulsar-green ((t :background ,bg-green)))
+            `(pulsar-magenta ((t :background ,bg-magenta)))
+            `(pulsar-red ((t :background ,bg-red)))
+            `(pulsar-yellow ((t :background ,bg-yellow)))
+
             '(rcirc-monospace-text ((t :inherit fixed-pitch)))
             '(rcirc-server ((t :inherit font-lock-comment-face)))
 
@@ -1595,6 +1653,9 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
             `(whitespace-tab ((t :foreground ,bg-shadow-intense)))))
          (custom-theme-set-variables
           ',name
+          `(flymake-error-bitmap '(flymake-double-exclamation-mark doric-themes-prominent-error))
+          `(flymake-warning-bitmap '(exclamation-mark doric-themes-prominent-warning))
+          `(flymake-note-bitmap '(exclamation-mark doric-themes-prominent-note))
           '(frame-background-mode ',background-mode)
           '(diff-font-lock-syntax nil))
          (provide-theme ',name))
